# Copyright (c) Lawrence Livermore National Security, LLC and other Conduit
# Project developers. See top-level LICENSE AND COPYRIGHT files for dates and
# other details. No copyright assignment is required to contribute to Conduit.

###############################################################################
# file: __init__.py
# Purpose: Main init for the conduit relay web module.
###############################################################################
from .conduit_relay_web_python import *







#  tests for conduit-0.8.0-py39h53d6734_0 (this is a generated file);
print('===== testing package: conduit-0.8.0-py39h53d6734_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import conduit
import conduit.blueprint
import conduit.relay
import conduit.relay.io

print(conduit.about())
print(conduit.blueprint.about())
print(conduit.relay.about())
print(conduit.relay.io.about())
#  --- run_test.py (end) ---

print('===== conduit-0.8.0-py39h53d6734_0 OK =====');
print("import: 'conduit'")
import conduit

print("import: 'conduit.relay'")
import conduit.relay

print("import: 'conduit.blueprint'")
import conduit.blueprint




# Copyright (c) Lawrence Livermore National Security, LLC and other Conduit
# Project developers. See top-level LICENSE AND COPYRIGHT files for dates and
# other details. No copyright assignment is required to contribute to Conduit.

"""
 file: conduit_python_example.py

 description:
   Basic conduit python usage

"""

import conduit
import conduit.relay
import conduit.blueprint

# print details about conduit
print(conduit.about())
print(conduit.relay.about())
print(conduit.blueprint.about())

# create a conduit node
n = conduit.Node()
n["a/b/c/d/e/f/g"] = 42
print(n)





